summaryrefslogtreecommitdiffstats
path: root/media/libmediaplayerservice/MediaPlayerService.cpp
diff options
context:
space:
mode:
authorAndy McFadden <fadden@android.com>2012-12-18 09:46:54 -0800
committerAndy McFadden <fadden@android.com>2012-12-18 13:31:57 -0800
commit484566c410afdfbc4b6bc5aa1732aef37428a5b8 (patch)
tree5ce1fc6a755c32f0b6ff362fe1fc5bf0d9ee2b14 /media/libmediaplayerservice/MediaPlayerService.cpp
parent34d7db5dd43000cac7e8e156d79e9f97ccbb8990 (diff)
downloadframeworks_av-484566c410afdfbc4b6bc5aa1732aef37428a5b8.zip
frameworks_av-484566c410afdfbc4b6bc5aa1732aef37428a5b8.tar.gz
frameworks_av-484566c410afdfbc4b6bc5aa1732aef37428a5b8.tar.bz2
Rename ISurfaceTexture and SurfaceTexture
The C++ class names don't match what the classes do, so rename ISurfaceTexture to IGraphicBufferProducer, and SurfaceTexture to GLConsumer. Bug 7736700 Change-Id: I64520a55f8c09fe6215382ea361c539a9940cba5
Diffstat (limited to 'media/libmediaplayerservice/MediaPlayerService.cpp')
-rw-r--r--media/libmediaplayerservice/MediaPlayerService.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/media/libmediaplayerservice/MediaPlayerService.cpp b/media/libmediaplayerservice/MediaPlayerService.cpp
index c3e5c40..4ca0811 100644
--- a/media/libmediaplayerservice/MediaPlayerService.cpp
+++ b/media/libmediaplayerservice/MediaPlayerService.cpp
@@ -714,21 +714,21 @@ void MediaPlayerService::Client::disconnectNativeWindow() {
}
status_t MediaPlayerService::Client::setVideoSurfaceTexture(
- const sp<ISurfaceTexture>& surfaceTexture)
+ const sp<IGraphicBufferProducer>& bufferProducer)
{
- ALOGV("[%d] setVideoSurfaceTexture(%p)", mConnId, surfaceTexture.get());
+ ALOGV("[%d] setVideoSurfaceTexture(%p)", mConnId, bufferProducer.get());
sp<MediaPlayerBase> p = getPlayer();
if (p == 0) return UNKNOWN_ERROR;
- sp<IBinder> binder(surfaceTexture == NULL ? NULL :
- surfaceTexture->asBinder());
+ sp<IBinder> binder(bufferProducer == NULL ? NULL :
+ bufferProducer->asBinder());
if (mConnectedWindowBinder == binder) {
return OK;
}
sp<ANativeWindow> anw;
- if (surfaceTexture != NULL) {
- anw = new SurfaceTextureClient(surfaceTexture);
+ if (bufferProducer != NULL) {
+ anw = new SurfaceTextureClient(bufferProducer);
status_t err = native_window_api_connect(anw.get(),
NATIVE_WINDOW_API_MEDIA);
@@ -745,10 +745,10 @@ status_t MediaPlayerService::Client::setVideoSurfaceTexture(
}
}
// Note that we must set the player's new SurfaceTexture before
// disconnecting the old one. Otherwise queue/dequeue calls could be made
// on the disconnected ANW, which may result in errors.
- status_t err = p->setVideoSurfaceTexture(surfaceTexture);
+ status_t err = p->setVideoSurfaceTexture(bufferProducer);
disconnectNativeWindow();
@@ -745,10 +745,10 @@ status_t MediaPlayerService::Client::setVideoSurfaceTexture(
}
}
- // Note that we must set the player's new SurfaceTexture before
+ // Note that we must set the player's new GraphicBufferProducer before
// disconnecting the old one. Otherwise queue/dequeue calls could be made
// on the disconnected ANW, which may result in errors.